@@ -1238,15 +1238,16 @@ class ClientTest(TestCase):
 
     def test_reaction_filter_random(self):
         self.c.reactions.filter(
-            reaction_id="54a60c1e-4ee3-494b-a1e3-50c06acb5ed4",
-            id_lte="54a60c1e-4ee3-494b-a1e3-50c06acb5ed4",
+            kind="like",
+            reaction_id="87a9eec0-fd5f-11e8-8080-80013fed2f5b",
+            id_lte="87a9eec0-fd5f-11e8-8080-80013fed2f5b",
         )
         self.c.reactions.filter(
-            activity_id="54a60c1e-4ee3-494b-a1e3-50c06acb5ed4",
-            id_lte="54a60c1e-4ee3-494b-a1e3-50c06acb5ed4",
+            activity_id="87a9eec0-fd5f-11e8-8080-80013fed2f5b",
+            id_lte="87a9eec0-fd5f-11e8-8080-80013fed2f5b",
         )
         self.c.reactions.filter(
-            user_id="mike", id_lte="54a60c1e-4ee3-494b-a1e3-50c06acb5ed4"
+            user_id="mike", id_lte="87a9eec0-fd5f-11e8-8080-80013fed2f5b"
         )
 
     def _first_result_should_be(self, response, element):
@@ -1262,15 +1263,24 @@ class ClientTest(TestCase):
         response = self.c.reactions.add("like", activity_id, user)
         child = self.c.reactions.add_child("like", response["id"], user)
         reaction = self.c.reactions.get(response["id"])
+
+        response = self.c.reactions.add("comment", activity_id, user)
+        reaction_comment = self.c.reactions.get(response["id"])
+
         r = self.c.reactions.filter(reaction_id=reaction["id"])
         self._first_result_should_be(r, child)
 
-        r = self.c.reactions.filter(activity_id=activity_id, id_lte=reaction["id"])
+        r = self.c.reactions.filter(
+            kind="like", activity_id=activity_id, id_lte=reaction["id"]
+        )
         self._first_result_should_be(r, reaction)
 
-        r = self.c.reactions.filter(user_id=user, id_lte=reaction["id"])
+        r = self.c.reactions.filter(kind="like", user_id=user, id_lte=reaction["id"])
         self._first_result_should_be(r, reaction)
 
+        r = self.c.reactions.filter(kind="comment", activity_id=activity_id)
+        self._first_result_should_be(r, reaction_comment)
+
     def test_user_add(self):
         self.c.users.add(str(uuid1()))
 
